@@ -1,6 +1,8 @@
+from .models import NotificationHistory
+from .models import UserDevice
 from django.contrib import admin
-
-from .models import NotificationHistory, UserDevice
+from fcm_django.admin import DeviceAdmin
+from fcm_django.models import FCMDevice
 
 
 @admin.register(NotificationHistory)
@@ -18,3 +20,11 @@ class NotificationHistoryAdmin(admin.ModelAdmin):
         "get_users",
         "subject",
     )
+
+
+admin.site.unregister(FCMDevice)
+
+
+@admin.register(UserDevice)
+class UserDeviceAdmin(DeviceAdmin):
+    pass
